==> kubernetes-model-autoscaling-4.13.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface HorizontalPodAutoscalerSpecFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBehavior instead.
 * @return The buildable object.
 */
@Deprecated public HorizontalPodAutoscalerBehavior getBehavior();
    public HorizontalPodAutoscalerBehavior buildBehavior();
    public A withBehavior(HorizontalPodAutoscalerBehavior behavior);
    public Boolean hasBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Boolean hasMaxReplicas();
    public A addToMetrics(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public A setToMetrics(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public A addToMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec... items);
    public A addAllToMetrics(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> items);
    public A removeFromMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec... items);
    public A removeAllFromMetrics(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> items);
    public A removeMatchingFromMetrics(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> getMetrics();
    public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> buildMetrics();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildMetric(int index);
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildFirstMetric();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildLastMetric();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    public Boolean hasMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    public A withMetrics(List<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> metrics);
    public A withMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec... metrics);
    public Boolean hasMetrics();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(int index);
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public Boolean hasMinReplicas();
    
/**
 * This method has been deprecated, please use method buildScaleTargetRef instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference getScaleTargetRef();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference buildScaleTargetRef();
    public A withScaleTargetRef(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference scaleTargetRef);
    public Boolean hasScaleTargetRef();
    public A withNewScaleTargetRef(String apiVersion,String kind,String name);
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item);
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item);
    public interface BehaviorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HorizontalPodAutoscalerBehaviorFluent<HorizontalPodAutoscalerSpecFluent.BehaviorNested<N>> {

        public N and();
        public N endBehavior();    }


    public interface MetricsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<HorizontalPodAutoscalerSpecFluent.MetricsNested<N>> {

        public N and();
        public N endMetric();    }


    public interface ScaleTargetRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>> {

        public N and();
        public N endScaleTargetRef();    }


}

==> kubernetes-model-autoscaling-5.0.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface HorizontalPodAutoscalerSpecFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBehavior instead.
 * @return The buildable object.
 */
@Deprecated public HorizontalPodAutoscalerBehavior getBehavior();
    public HorizontalPodAutoscalerBehavior buildBehavior();
    public A withBehavior(HorizontalPodAutoscalerBehavior behavior);
    public Boolean hasBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehavior();
    public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Boolean hasMaxReplicas();
    public A addToMetrics(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public A setToMetrics(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public A addToMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec... items);
    public A addAllToMetrics(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> items);
    public A removeFromMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec... items);
    public A removeAllFromMetrics(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> items);
    public A removeMatchingFromMetrics(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> getMetrics();
    public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> buildMetrics();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildMetric(int index);
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildFirstMetric();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildLastMetric();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec buildMatchingMetric(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    public Boolean hasMatchingMetric(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    public A withMetrics(List<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec> metrics);
    public A withMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec... metrics);
    public Boolean hasMetrics();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec item);
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(int index);
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
    public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> predicate);
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public Boolean hasMinReplicas();
    
/**
 * This method has been deprecated, please use method buildScaleTargetRef instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference getScaleTargetRef();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference buildScaleTargetRef();
    public A withScaleTargetRef(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference scaleTargetRef);
    public Boolean hasScaleTargetRef();
    public A withNewScaleTargetRef(String apiVersion,String kind,String name);
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item);
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
    public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item);
    public interface BehaviorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HorizontalPodAutoscalerBehaviorFluent<HorizontalPodAutoscalerSpecFluent.BehaviorNested<N>> {

            public N and();
            public N endBehavior();    }


    public interface MetricsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<HorizontalPodAutoscalerSpecFluent.MetricsNested<N>> {

            public N and();
            public N endMetric();    }


    public interface ScaleTargetRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>> {

            public N and();
            public N endScaleTargetRef();    }


}
